@@ -1,4 +1,4 @@
-from PyQt6.QtWidgets import QMainWindow, QMenu, QApplication, QLabel, QFileDialog, QStyleFactory, QDialog, QColorDialog, QInputDialog
+from PyQt6.QtWidgets import QMainWindow, QMenu, QApplication, QLabel, QFileDialog, QStyleFactory, QDialog, QColorDialog, QInputDialog, QMessageBox
 from PyQt6.Qsci import QsciScintilla, QsciScintillaBase, QsciMacro, QsciPrinter
 from PyQt6.QtGui import QIcon, QAction
 from PyQt6.QtPrintSupport import QPrintDialog
@@ -619,6 +619,14 @@ class MainWindow(QMainWindow):
         self.toolsMenu.addAction(replaceSpacesTabAction)
         self.env.pluginAPI.addAction(replaceSpacesTabAction)
 
+        self.toolsMenu.addSeparator()
+
+        regExGrepAction = QAction(QCoreApplication.translate("MainWindow", "RegExGrep"))
+        regExGrepAction.triggered.connect(lambda : self.env.regExGrepWindow.show())
+        regExGrepAction.setData(["regExGrep"])
+        self.toolsMenu.addAction(regExGrepAction)
+        self.env.pluginAPI.addAction(regExGrepAction)
+
         self.languageMenu = self.menubar.addMenu("&" + self.env.translate("mainWindow.menu.language"))
 
         #self.updateLanguageMenu()
@@ -687,12 +695,12 @@ class MainWindow(QMainWindow):
         self.executeMenu = self.menubar.addMenu(self.env.translate("mainWindow.menu.execute"))
 
         self.executeCommandAction = QAction(self.env.translate("mainWindow.menu.execute.executeCommand"), self)
-        self.executeCommandAction.triggered.connect(lambda: self.env.executeCommandWindow.openWindow(self.getTextEditWidget()) if self.checkFlatpakBox() else str())
+        self.executeCommandAction.triggered.connect(lambda: self.env.executeCommandWindow.openWindow(self.getTextEditWidget()))
         self.executeCommandAction.setData(["executeCommand"])
         self.env.pluginAPI.addAction(self.executeCommandAction)
 
         self.editCommandsAction = QAction(self.env.translate("mainWindow.menu.execute.editCommands"), self)
-        self.editCommandsAction.triggered.connect(lambda: self.env.editCommandsWindow.openWindow() if self.checkFlatpakBox() else str())
+        self.editCommandsAction.triggered.connect(lambda: self.env.editCommandsWindow.openWindow())
         self.editCommandsAction.setData(["editCommands"])
         self.env.pluginAPI.addAction(self.editCommandsAction)
 
@@ -747,6 +755,20 @@ class MainWindow(QMainWindow):
 
         self.aboutMenu.addSeparator()
 
+        debugInfoAction = QAction(QCoreApplication.translate("MainWindow", "Debug information"), self)
+        debugInfoAction.triggered.connect(lambda : self.env.debugInfoWindow.openWindow())
+        debugInfoAction.setData(["debugInfo"])
+        self.aboutMenu.addAction(debugInfoAction)
+        self.env.pluginAPI.addAction(debugInfoAction)
+
+        deleteAllDataAction = QAction(QCoreApplication.translate("MainWindow", "Delete all data"), self)
+        deleteAllDataAction.triggered.connect(self.deleteAllData)
+        deleteAllDataAction.setData(["deleteAllData"])
+        self.aboutMenu.addAction(deleteAllDataAction)
+        self.env.pluginAPI.addAction(deleteAllDataAction)
+
+        self.aboutMenu.addSeparator()
+
         about = QAction(self.env.translate("mainWindow.menu.about.about"),self)
         about.triggered.connect(lambda: self.env.aboutWindow.show())
         about.setData(["about"])
@@ -1025,32 +1047,19 @@ class MainWindow(QMainWindow):
             command.setData([False,i[1],i[2]])
             if len(i) == 4:
                 command.setShortcut(i[3])
-            if self.env.isFlatpak:
-                command.triggered.connect(self.checkFlatpakBox)
-            else:
-                command.triggered.connect(lambda sender: executeCommand(self.env, self.sender().data()[1], self.getTextEditWidget(), self.sender().data()[2]))
+            command.triggered.connect(lambda sender: executeCommand(self.env, self.sender().data()[1], self.getTextEditWidget(), self.sender().data()[2]))
             self.executeMenu.addAction(command)
 
         for i in self.env.global_commands:
             command = QAction(i[0],self)
             command.setData([False, i[1], i[2]])
-            if self.env.isFlatpak:
-                command.triggered.connect(self.checkFlatpakBox)
-            else:
-                command.triggered.connect(lambda sender: executeCommand(self.env, self.sender().data()[1], self.getTextEditWidget(), self.sender().data()[2]))
+            command.triggered.connect(lambda sender: executeCommand(self.env, self.sender().data()[1], self.getTextEditWidget(), self.sender().data()[2]))
             self.executeMenu.addAction(command)
 
         self.executeMenu.addSeparator()
 
         self.executeMenu.addAction(self.editCommandsAction)
 
-    def checkFlatpakBox(self) -> bool:
-        if not self.env.isFlatpak:
-            return True
-        else:
-            showMessageBox(QCoreApplication.translate("MainWindow", "Not available in Flatpak"),
-                           QCoreApplication.translate("MainWindow", "This feature is not available when you run jdTextEdit as Flatpak due the Sandbox restrictions"))
-            return False
 
     def openFile(self, path: str, template=None, reload=None):
         #Check if the file is already open
@@ -1554,6 +1563,19 @@ class MainWindow(QMainWindow):
         with open(os.path.join(self.env.dataDir,"macros.json"), 'w', encoding='utf-8') as f:
             json.dump(self.env.macroList, f, ensure_ascii=False, indent=4)
 
+    def deleteAllData(self):
+        if QMessageBox.question(self, QCoreApplication.translate("MainWindow", "Delete all data"), QCoreApplication.translate("MainWindow", "This will delete all data of jdTextEdit. After that, jdTextEdit will behave like the first run. jdTexEdit will exit after doing that. Are you sure?")) != QMessageBox.StandardButton.Yes:
+            return
+
+        try:
+            shutil.rmtree(self.env.dataDir)
+        except Exception:
+            print(traceback.format_exc(), end="", file=sys.stderr)
+            showMessageBox(self.env.translate("unknownError.title"), self.env.translate("unknownError.text"))
+            return
+
+        sys.exit(0)
+
     def autoSaveTimeout(self):
         if self.autoSaveTimer.timeout == 0 or not self.env.settings.enableAutoSave:
             return
@@ -1637,6 +1659,7 @@ class MainWindow(QMainWindow):
             saveWindowState(self.env.dateTimeWindow, windowState, "DateTimeWindow")
             saveWindowState(self.env.manageMacrosWindow, windowState, "ManageMacrosWindow")
             saveWindowState(self.env.actionSearchWindow, windowState, "ActionSearchWindow")
+            saveWindowState(self.env.debugInfoWindow, windowState, "DebugInfoWindow")
             with open(os.path.join(self.env.dataDir, "windowstate.json"), 'w', encoding='utf-8') as f:
                 json.dump(windowState, f, ensure_ascii=False, indent=4)
         else:
@@ -1644,6 +1667,8 @@ class MainWindow(QMainWindow):
                 os.remove(os.path.join(self.env.dataDir,"windowstate.json"))
             except:
                 pass
+        with open(os.path.join(self.env.dataDir, "lastversion.txt"), "w", encoding="utf-8") as f:
+            f.write(self.env.version)
 
     def closeEvent(self, event):
         self.saveDataClose()
