@@ -17,6 +17,8 @@ from jdTextEdit.gui.DayTipWindow import DayTipWindow
 from jdTextEdit.gui.ActionSearchWindow import ActionSearchWindow
 from jdTextEdit.gui.AboutWindow import AboutWindow
 from jdTextEdit.gui.AddProjectWindow import AddProjectWindow
+from jdTextEdit.gui.Tools.RegExGrep.RegExGrepWindow import RegExGrepWindow
+from jdTextEdit.gui.DebugInfoWindow import DebugInfoWindow
 from jdTextEdit.Functions import getTempOpenFilePath
 from jdTextEdit.core.PluginLoader import loadPlugins
 import time
@@ -62,6 +64,8 @@ def main():
     env.actionSearchWindow = ActionSearchWindow(env)
     env.aboutWindow = AboutWindow(env)
     env.addProjectWindow = AddProjectWindow(env)
+    env.regExGrepWindow = RegExGrepWindow(env)
+    env.debugInfoWindow = DebugInfoWindow(env)
     if env.settings.get("loadPlugins") and not env.args["disablePlugins"]:
         loadPlugins(os.path.join(env.programDir,"plugins"),env)
         loadPlugins(os.path.join(env.dataDir,"plugins"),env)
